<?php
$lang['expired_searchable'] = 'Expired articles can appear in search results';
$lang['helpshowall'] = 'Show all articles, irrespective of end date';
$lang['error_invaliddates'] = 'One or more of the dates entered were invalid';
$lang['notify_n_draft_items_sub'] = 'Naujienų straipsnių: %d ';
$lang['notify_n_draft_items'] = 'You have %s that is/are not published';
$lang['unlimited'] = 'Neribojama';
$lang['none'] = 'Nei vienas';
$lang['anonymous'] = 'Anoniminis';
$lang['unknown'] = 'Nežinomas';
$lang['fesubmit_redirect'] = 'ID ar puslapio trumpinys kur bus nukreiptas po naujienos pateikimo naudojant fesubmint veiksmą';
$lang['allow_summary_wysiwyg'] = 'Leisti naudotis WYSIWYG redaktoriumi santraukos  formoje';
$lang['title_browsecat_template'] = 'Kategorijų nar&scaron;ymo &scaron;ablonų redaktorius';
$lang['title_browsecat_sysdefault'] = 'Įprastas kategorijų nar&scaron;ymo &scaron;ablonas';
$lang['browsecattemplate'] = 'Kategorijų nar&scaron;ymo &scaron;ablonai';
$lang['error_filesize'] = 'Atsiųsta byla pasiekė maksimaliai leidžiama dydį';
$lang['post_date_desc'] = 'Pagal įra&scaron;o datą mažėjančiai';
$lang['post_date_asc'] = 'Pagal įra&scaron;o datą didėjančiai';
$lang['expiry_date_desc'] = 'Pasibaigimo datą mažėjančiai';
$lang['expiry_date_asc'] = 'Pasibaigimo datą didėjančiai';
$lang['title_desc'] = 'Pavadinimą mažėjančiai';
$lang['title_asc'] = 'Pavadinimą didėjančiai';
$lang['fesubmit_status'] = 'Straipsnių būsena kurie pateikti &quot;priekinių&quot; narių';
$lang['error_invalidfiletype'] = '&Scaron;io tipo bylų siųsti negalima';
$lang['error_upload'] = 'Problemos su siunčiama byla';
$lang['error_movefile'] = 'Neįmanoma sukurti bylos: %s';
$lang['error_mkdir'] = 'Neįmanoma sukurti katalogo: %s';
$lang['expiry_interval'] = 'Dienų skaičius (įprastai) po kurio baigs galioti straipsnis (jei pasirinkta)';
$lang['removed'] = 'Pa&scaron;alinta';
$lang['msg_contenttype_removed'] = 'Naujienų turinio tipas buvo pa&scaron;alintas. Pra&scaron;ome naudoti {news} žymę su atitinkamais parametrais puslapio &scaron;ablome arba puslapio turinyje.';
$lang['delete_selected'] = 'I&scaron;trinti pasirinktus straipsnius';
$lang['areyousure_deletemultiple'] = 'Ar jūs tikrai norite i&scaron;trinti pasirinktus straipsnius?\n &Scaron;is veiksmas negrįžtamas!';
$lang['error_templatenamexists'] = '&Scaron;ablonas tokiu pavadinimu jau yra';
$lang['error_noarticlesselected'] = 'Nepasirinkta straipsnių';
$lang['reassign_category'] = 'Pakeisti kategorija į';
$lang['select'] = 'Pasirinkt';
$lang['approve'] = 'Nustatyti į būsena  &#039;Paskelbta&#039;';
$lang['revert'] = 'Nustatyti į būsena  &#039;Juodra&scaron;tis&#039;';
$lang['hide_summary_field'] = 'Paslėpti santraukos lauką kai pridedamas ar redaguojamas straipsnis';
$lang['textbox'] = 'Teksto įvestis';
$lang['checkbox'] = 'Žymimasis langelis';
$lang['textarea'] = 'Teksto sritis';
$lang['file'] = 'Byla';
$lang['auto_create_thumbnails'] = 'Automati&scaron;kai sukurti thumbnail &scaron;ioms byloms ';
$lang['allowed_upload_types'] = 'Leisti tik &scaron;ių bylų atsiuntimą';
$lang['fielddefupdated'] = 'Laukelio tikslas atnaujintas';
$lang['editfielddef'] = 'Redaguoti laukelio tikslą';
$lang['up'] = 'Vir&scaron;un';
$lang['down'] = 'Žemyn';
$lang['fielddefdeleted'] = 'Laukelio tikslas i&scaron;trintas';
$lang['nameexists'] = 'Laukelis tokiu pavadinimų jau yra';
$lang['notanumber'] = 'Maksimalus ilgis nėra skaičius';
$lang['fielddef'] = 'Laukelio Tikslas';
$lang['fielddefadded'] = 'Sėkmingai pridėtas laukelio tikslas';
$lang['public'] = 'Vie&scaron;as';
$lang['type'] = 'Tipas';
$lang['info_maxlength'] = 'Maksimalus ilgis taikomas tik teksto įvesties laukeliuose';
$lang['maxlength'] = 'Maksimalus ilgis';
$lang['addfielddef'] = 'Pridėti laukelio apibrėžimą';
$lang['customfields'] = 'Laukelių apibrėžimai';
$lang['deprecated'] = 'nepalaikoma';
$lang['subject_newnews'] = 'Naujas Naujienų straipsnis';
$lang['email_subject'] = 'Temos pavadinimas';
$lang['email_template'] = 'El. pa&scaron;to žinutės formatas';
$lang['formsubmit_emailaddress'] = 'El. pa&scaron;to adresas kuri gaus įspėjimus apie naujus pateikimus';
$lang['extra'] = 'Papildomas';
$lang['uploadscategory'] = 'Atsiuntimo kategorija';
$lang['title_available_templates'] = 'Galimi &scaron;ablonai';
$lang['resettodefault'] = 'Nustatyti pradinius nustatymus';
$lang['title_form_template'] = 'Formos &scaron;ablono redaktorius';
$lang['title_detail_template'] = 'Detalaus &scaron;ablono redaktorius';
$lang['title_summary_template'] = 'Santraukos &scaron;ablono redaktorius';
$lang['prompt_templatename'] = '&Scaron;ablono pavadinimas';
$lang['prompt_template'] = '&Scaron;ablono &scaron;altinis';
$lang['title_form_sysdefault'] = 'Įprastas formos &scaron;ablonas ';
$lang['title_summary_sysdefault'] = 'Įprastas santraukos &scaron;ablonas';
$lang['title_detail_sysdefault'] = 'Įprastas detalus &scaron;ablonas';
$lang['info_sysdefault2'] = '<strong>Dėmesio:</strong> &Scaron;ioje kortelėje esančios teksto sritys kuriose yra &scaron;ablonai kurie rodomi kai paspaudžiamas &#039;kurti naują&#039; santraukos, detalus, formos &scaron;ablonus. Turinio pakeitimas &scaron;ioje kortelėje  <strong>neturės jokios įtakos esamiems &scaron;ablonams</strong>
';
$lang['info_sysdefault'] = '<em>(turinys naudojamas kai kuriamas naujas &scaron;ablonas)</em>';
$lang['template'] = '&Scaron;ablonas';
$lang['prompt_name'] = 'Pavadinimas';
$lang['prompt_default'] = 'Įprastas';
$lang['prompt_newtemplate'] = 'Sukurti naują &scaron;abloną';
$lang['help_pagelimit'] = 'Maksimalus rodomų elementų kiekis puslapyje. Jei &scaron;is parametras nenustatytas visi elementai bus rodomi. Jei nustatyta ir elementų yra daugiau tekstas ir nuorodos bus pateiktos taip, kad būtų įmanoma juos peržvelgi';
$lang['prompt_page'] = 'Puslapis';
$lang['firstpage'] = '<<';
$lang['prevpage'] = '<';
$lang['nextpage'] = '>';
$lang['lastpage'] = '>>';
$lang['prompt_of'] = 'i&scaron;';
$lang['prompt_pagelimit'] = 'Puslapių limitas';
$lang['prompt_sorting'] = 'Rūų&scaron;iuoti pagal';
$lang['title_filter'] = 'Filtrai';
$lang['published'] = 'Paskelbtas';
$lang['draft'] = 'Juodra&scaron;tis';
$lang['expired'] = 'Baigėsi';
$lang['author'] = 'Autorius';
$lang['sysdefaults'] = 'Atstayti įprastus nustatymus';
$lang['restoretodefaultsmsg'] = '&Scaron;is veiksmas atstatys turinio &scaron;abloną į sistemos įprasta.  Ar tikrai norite tęsti?';
$lang['addarticle'] = 'Įdėti Straipsnį';
$lang['articleadded'] = 'Naujas straipsnis sėkmingai įdėtas.';
$lang['articleupdated'] = 'Straipsnis sėkmingai atnaujintas.';
$lang['articledeleted'] = 'Straipsnis sėkmingai i&scaron;trintas.';
$lang['addcategory'] = 'Įdėti Kategoriją';
$lang['categoryadded'] = 'Kategorija sėkmingai sukurta.';
$lang['categoryupdated'] = 'Kategorija sėkmingai atnaujinta.';
$lang['categorydeleted'] = 'Kategorija sėkmingai i&scaron;trinta..';
$lang['addnewsitem'] = 'Įdėti Naujienų Elementą';
$lang['allcategories'] = 'Visos Kategorijos';
$lang['allentries'] = 'Visi Įra&scaron;ai';
$lang['areyousure'] = 'Ar tikrai norite i&scaron;trinti?';
$lang['articles'] = 'Straipsniai';
$lang['cancel'] = 'At&scaron;aukti';
$lang['category'] = 'Kategorija';
$lang['categories'] = 'Kategorijos';
$lang['default_category'] = 'Įprasta kategorija';
$lang['content'] = 'Turinys';
$lang['dateformat'] = '%s negalimas yyyy-mm-dd hh:mm:ss formatas';
$lang['delete'] = 'Trinti';
$lang['description'] = 'Įdėti, redaguoti ir trinti Naujienų įra&scaron;us';
$lang['formtemplate'] = 'Formos &Scaron;ablonas';
$lang['detailtemplate'] = 'Detalus &Scaron;ablonas';
$lang['default_templates'] = 'Įprastas &Scaron;ablonas';
$lang['detailtemplateupdated'] = 'Detalaus &scaron;ablono atnaujinimas i&scaron;saugotas.';
$lang['displaytemplate'] = 'Rodyti &Scaron;abloną';
$lang['edit'] = 'Redaguoti';
$lang['enddate'] = 'Baigimosi Data';
$lang['endrequiresstart'] = 'Įvedant baigimosi datą, reikia taip pat įvesti ir pradžios datą';
$lang['entries'] = '%s Įra&scaron;ai';
$lang['status'] = 'Būklė';
$lang['expiry'] = 'Galiojimas';
$lang['filter'] = 'Filtruoti';
$lang['more'] = 'Daugiau';
$lang['category_label'] = 'Kategorija:';
$lang['author_label'] = 'Įra&scaron;ė:';
$lang['moretext'] = 'Daugiau teksto';
$lang['name'] = 'Vardas';
$lang['news'] = 'Naujienos';
$lang['news_return'] = 'grįžti';
$lang['newcategory'] = 'Nauja Kategorija';
$lang['needpermission'] = 'Jums reikia prieigos &#039;%s&#039; tam, kad atlikti &scaron;ią funkciją.';
$lang['nocategorygiven'] = 'Neužpildyta Kategorija';
$lang['startdatetoolate'] = 'Pradžios data per vėlai (po pabaigos data?)';
$lang['nocontentgiven'] = 'Neužpildytas Turinys';
$lang['noitemsfound'] = '<strong>Nerasta</strong> įra&scaron;ų &scaron;ioje kategorijoje: %s';
$lang['nopostdategiven'] = 'Neužpildyta įra&scaron;o pateikimo data';
$lang['note'] = '<em>Žyma:</em> Datos turi būti &#039;yyyy-mm-dd hh:mm:ss&#039; formato.';
$lang['notitlegiven'] = 'Neužpildytas Pavadinimas';
$lang['nonamegiven'] = 'Neužpildytas vardas';
$lang['numbertodisplay'] = 'Rodomas Skaičius (palikus tu&scaron;čią, rodomi visi įra&scaron;ai)';
$lang['print'] = 'Spausdinti';
$lang['postdate'] = 'Įra&scaron;o data';
$lang['postinstall'] = 'Nustatykite &quot;Redaguoti Naujienas (Modify News)&quot; prieigą tiems vartotojams, kurie administruos naujienas.';
$lang['selectcategory'] = 'Pasirinkite Kategoriją';
$lang['showchildcategories'] = 'Rodyti subkategorijas';
$lang['sortascending'] = 'Rū&scaron;iuoti Didėjančiai';
$lang['startdate'] = 'Pradžios Data';
$lang['startoffset'] = 'Pradėti rodyti nth elemtą';
$lang['startrequiresend'] = 'Įvedant pradžios datą, reikia įvesti ir pabaigos datą';
$lang['submit'] = 'Pateikti';
$lang['summary'] = 'Santrauka';
$lang['summarytemplate'] = 'Santraukos &Scaron;ablonas';
$lang['summarytemplateupdated'] = 'Naujienų santraukos &scaron;ablonas atnaujintas sėkmingai.';
$lang['title'] = 'Pavadinimas';
$lang['options'] = 'Nustatymai';
$lang['optionsupdated'] = 'Nustaymai atnaujinti.';
$lang['useexpiration'] = 'Naudoti galiojimo datą';
$lang['eventdesc-NewsArticleAdded'] = 'Nusiųsti kai straipsnis įdėtas.';
$lang['eventhelp-NewsArticleAdded'] = '<p>Sent when an article is added.</p>
<h4>Parameters</h4>
<ul>
<li>\&quot;news_id\&quot; - Id of the news article</li>
<li>\&quot;category_id\&quot; - Id of the category for this article</li>
<li>\&quot;title\&quot; - Title of the article</li>
<li>\&quot;content\&quot; - Content of the article</li>
<li>\&quot;summary\&quot; - Summary of the article</li>
<li>\&quot;status\&quot; - Status of the article (&quot;draft&quot; or &quot;publish&quot;)</li>
<li>\&quot;start_time\&quot; - Date the article should start being displayed</li>
<li>\&quot;end_time\&quot; - Date the article should stop being displayed</li>
<li>\&quot;useexp\&quot; - Wether the expiration date should be ignored or not</li>
</ul>
';
$lang['eventdesc-NewsArticleEdited'] = 'Nusiųsti kai straipsnis redaguotas.';
$lang['eventhelp-NewsArticleEdited'] = '<p>Sent when an article is edited.</p>
<h4>Parameters</h4>
<ul>
<li>\&quot;news_id\&quot; - Id of the news article</li>
<li>\&quot;category_id\&quot; - Id of the category for this article</li>
<li>\&quot;title\&quot; - Title of the article</li>
<li>\&quot;content\&quot; - Content of the article</li>
<li>\&quot;summary\&quot; - Summary of the article</li>
<li>\&quot;status\&quot; - Status of the article (&quot;draft&quot; or &quot;publish&quot;)</li>
<li>\&quot;start_time\&quot; - Date the article should start being displayed</li>
<li>\&quot;end_time\&quot; - Date the article should stop being displayed</li>
<li>\&quot;useexp\&quot; - Wether the expiration date should be ignored or not</li>
</ul>
';
$lang['eventdesc-NewsArticleDeleted'] = 'Nusiųsti kai straipsnis i&scaron;trintas.';
$lang['eventhelp-NewsArticleDeleted'] = '<p>Sent when an article is deleted.</p>
<h4>Parameters</h4>
<ul>
<li>\&quot;news_id\&quot; - Id of the news article</li>
</ul>
';
$lang['eventdesc-NewsCategoryAdded'] = 'Nusiųsti kai kategorija pridėta.';
$lang['eventhelp-NewsCategoryAdded'] = '<p>Sent when a category is added.</p>
<h4>Parameters</h4>
<ul>
<li>\&quot;category_id\&quot; - Id of the news category</li>
<li>\&quot;name\&quot; - Name of the news category</li>
</ul>
';
$lang['eventdesc-NewsCategoryEdited'] = 'Nusiųsti kai kategorija redaguota.';
$lang['eventhelp-NewsCategoryEdited'] = '<p>Sent when a category is edited.</p>
<h4>Parameters</h4>
<ul>
<li>\&quot;category_id\&quot; - Id of the news category</li>
<li>\&quot;name\&quot; - Name of the news category</li>
<li>\&quot;origname\&quot; - The original name of the news category</li>
</ul>
';
$lang['eventdesc-NewsCategoryDeleted'] = 'Nusiųsti kai kategorija i&scaron;trinta.';
$lang['eventhelp-NewsCategoryDeleted'] = '<p>Sent when a category is deleted.</p>
<h4>Parameters</h4>
<ul>
<li>\&quot;category_id\&quot; - Id of the deleted category </li>
<li>\&quot;name\&quot; - Name of the deleted category</li>
</ul>
';
$lang['help_articleid'] = 'This parameter is only applicable to the detail view.  It allows specifying which news article to display in detail mode.  If the special value -1 is used, the system will display the newest, published, non expired article.';
$lang['helpnumber'] = 'Maximalus rodomų elementų skaičius =- palikite tu&scaron;čia, rodys visus.';
$lang['helpstart'] = 'Pradėti nth elementu -- palikite tu&scaron;čia, pradės nuo pirmos.';
$lang['helpcategory'] = 'Rodo straipsnius tik i&scaron; nurodytos kategorijos. <b>Naudoti * po kategorijos jei rodyti subkategorijas.</b>  Daugiau kategorijų galima rodyti jei pavadinimai atskirti kableliais. Palikite tu&scaron;čia rodysite visas kategorijas. &Scaron;is parametras taip pat veikia su prie&scaron;akiniu pateikimo forma. bet palaiko tik vieną kategoriją.';
$lang['helpmoretext'] = 'Tekstas rodomas santraukos pabaigoje, nuoroda į straipsnio turinį. Įprastai &quot;more...&quot;';
$lang['helpsummarytemplate'] = 'Use a separate database template for displaying the article summary.  This template must exist and be visible in the summary template tab of the News admin, though it does not need to be the default.  If this parameter is not specified, then the current template marked as default will be used.';
$lang['helpformtemplate'] = 'Use a database template for displaying the article submission form. This template must exist and be visible in the form templates tab of the News admin, though it does not need to be the default.  If this parameter is not specified, then the current template marked as default will be used.';
$lang['helpbrowsecattemplate'] = 'Use a database template for displaying the category browser. This template must exist and be visible in the Browse Category Templates tab of the News admin, though it does not need to be the default.  If this parameter is not specified, then the current template marked as default will be used.';
$lang['helpdetailtemplate'] = 'Use a separate template for displaying the article detail.  It have to live in modules/News/templates.';
$lang['helpsortby'] = 'Field to sort by.  Options are: &quot;news_date&quot;, &quot;summary&quot;, &quot;news_data&quot;, &quot;news_category&quot;, &quot;news_title&quot;.  Defaults to &quot;news_date&quot;.';
$lang['helpsortasc'] = 'Sort news items in ascending date order rather than descending.';
$lang['helpdetailpage'] = 'Page to display News details in.  This can either be a page alias or an id. Used to allow details to be displayed in a different template from the summary.';
$lang['helpshowarchive'] = 'Rodyti tik pasibaigusio galiojimo naujienų straipsnius.';
$lang['helpbrowsecat'] = 'Rodyti nar&scaron;oma kategorijų sąra&scaron;ą.';
$lang['helpaction'] = 'Override the default action.  Possible values are &#039;default&#039; to display the summary view, and &#039;fesubmit&#039; to display the frontend form for allowing users to submit news articles on the front end.';
$lang['help'] = '	<h3>Ką jis daro?</h3>
	<p>Naujienų modulis rodo naujienas jūsų puslapyje, pana&scaron;iu kaip &#039;blog&#039; stiliumi, tik su daugiau galimybių. Kai meniu modulis įdiegtas, Naujienų administravimo puslapis yra įdedamas į meniu apačią, kuris jums leis parinkti ar pridėti naujienų kategoriją.</p>
	<h3>Saugumas</h3>
	<p>Vartotojas turi priklausyti grupei su prieiga &#039;Redaguoti Naujienas&#039; (&#039;Modify News&#039;), tam kad galėtu pridėti, redaguoti ar trinti naujienų įra&scaron;us.</p>
	<h3>Kaip jį naudoti?</h3>
	<p>Lengviausias būdas naudojant cms_module žymę. Bus įterptas modulis į jūsų &scaron;abloną ar puslapį ir rodys naujienų įra&scaron;us. Kodas turėtų būti pana&scaron;us kaip: <code>{cms_module module=&quot;news&quot; number=&quot;5&quot; category=&quot;beer&quot;}</code></p>
	<h3>Kokie parametrai egzistuoja?</h3>
	<p>
	<ul>
	<li><em>(optional)</em> number=&quot;5&quot; - Maksimalus rodomų įra&scaron;ų skaičius =- palikus tu&scaron;čią, bus rodomi visi įra&scaron;ai</li>
	<li><em>(optional)</em> makerssbutton=&quot;true&quot; - Sukuriamas naujienų įra&scaron;ų RSSui mygtukas.</li>
	<li><em>(optional)</em> category=&quot;category&quot; - Rodyti tik tos kategorijos įra&scaron;us ir jos vaikus. Palikus tu&scaron;čią, rodomos visos kategorijos.</li>
	<li><em>(optional)</em> moretext=&quot;more...&quot; - Tekstas, kuris rodomas kai naujiena vir&scaron;iją santrauką. Nustatytas &quot;more...&quot;.</li>
	<li><em>(optional}</em> summarytemplate=&quot;sometemplate.tpl&quot; - Naudokite atskirą &scaron;abloną rodyti naujienų santrauką. Jį reikia sukurti modules/News/templates.
	<li><em>(optional}</em> detailtemplate=&quot;sometemplate.tpl&quot; - Naudokite atskirą &scaron;abloną rodyti visas naujienas. Jį reikia sukurti modules/News/templates.
	<li><em>(optional)</em> sortby=&quot;news_date&quot; - Rū&scaron;iavimo laukas. Pasirinkimai: &quot;news_date&quot;, &quot;summary&quot;, &quot;news_data&quot;, &quot;news_category&quot;, &quot;news_title&quot;. Nustatyta: &quot;news_date&quot;.</li>
	<li><em>(optional)</em> sortasc=&quot;true&quot; - Rū&scaron;iuoti naujienas didėjančia tvarka.</li>
	</ul>
	</p>';
$lang['utmz'] = '156861353.1250297380.1752.42.utmccn=(referral)|utmcsr=helminsen.no|utmcct=/install/upgrade.php|utmcmd=referral';
$lang['utma'] = '156861353.179052623084110100.1210423577.1259353230.1259355475.2152';
$lang['qca'] = '1210971690-27308073-81952832';
$lang['utmc'] = '156861353';
$lang['utmb'] = '156861353.2.10.1259355475';
?>